@@ -1,15 +1,11 @@
-'''
-Created on Feb 22, 2011
 
-@author: vahid
-'''
 from jalali_date import JalaliDate, MAXYEAR, MINYEAR
 from jalali_datetime import JalaliDatetime
 from tehran_timezone import TehTz
 
 teh_tz = TehTz()
 
-__version__ = '0.9'
+__version__ = '0.9.1'
 
 
 __all__ = [
