@@ -1,14 +1,9 @@
-'''
-Created on Mar 8, 2011
 
-@author: vahid
-'''
-
-from datetime import tzinfo,timedelta
+from datetime import tzinfo, timedelta
 from khayyam.jalali_datetime import JalaliDatetime
 
-STDOFFSET = timedelta(minutes= 210) # Minutes
-DSTOFFSET = timedelta(minutes= 270) # Minutes
+STDOFFSET = timedelta(minutes=210) # Minutes
+DSTOFFSET = timedelta(minutes=270) # Minutes
 DSTDIFF = DSTOFFSET - STDOFFSET
 ZERO = timedelta(0)
 
@@ -22,18 +17,18 @@ class TehTz(tzinfo):
     
     def _isdst(self, dt):
         dt = dt.replace(tzinfo=None)
-        if isinstance(dt,JalaliDatetime):
+        if isinstance(dt, JalaliDatetime):
             jdt = dt
         else:
             jdt = JalaliDatetime.from_datetime(dt)
-        start_jdt = jdt.replace(month=1,day=1)
-        end_jdt = jdt.replace(month=7,day=1)
+        start_jdt = jdt.replace(month=1, day=1)
+        end_jdt = jdt.replace(month=7, day=1)
         if jdt > start_jdt and jdt < end_jdt:
             return True
         else:
             return False
     
-    def dst(self,dt):
+    def dst(self, dt):
         if self._isdst(dt):
             return DSTDIFF
         else:
@@ -43,7 +38,7 @@ class TehTz(tzinfo):
         #return 'Iran/Tehran'
         return self.format_offset(dt)
     
-    def format_offset(self,dt):
+    def format_offset(self, dt):
         offset = self.utcoffset(dt)
-        return '+%s:%s' % (offset.seconds/3600,(offset.seconds%3600)/60)
-        
\ No newline at end of file
+        return '+%s:%s' % (offset.seconds / 3600, (offset.seconds % 3600) / 60)
+        
